/*
 * tmos - mutex.h 
 * Copyright (C) 2009  Krzysztof Mazur <krzysiek@podlesie.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Fundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __ASM_MUTEX_H
#define __ASM_MUTEX_H

#include <tmos/sched.h>

typedef __bit mutex_t;

#define MUTEX_UNLOCKED (1)
#define MUTEX_LOCKED (0)

#define MUTEX_INITIALIZER MUTEX_UNLOCKED

#define mutex_is_locked(lock)	(lock == MUTEX_LOCKED)

#define DECLARE_MUTEX(name) \
	mutex_t name = MUTEX_INITIALIZER

#define mutex_lock(lock)	\
	for (;;) { \
		if ((lock) == MUTEX_UNLOCKED) { \
			(lock) = MUTEX_LOCKED; \
			break; \
		} \
		schedule(); \
	}

#define mutex_trylock(lock)	\
	(((lock) == MUTEX_UNLOCKED) ? (lock = MUTEX_LOCKED, 1) : 0)

#define mutex_unlock(lock) \
	do { \
		(lock) = MUTEX_UNLOCKED; \
	} while (0)

#endif
